<?php
/*
Plugin Name: BizVektor Garden
Plugin URI:
Description: BizVektorテーマ用の拡張デザインスキン「Garden」を追加するプラグインです。有効化した後に、デザイン選択のプルダウンで「Garden」が選択出来るようになります。
Author:Vektor,Inc.
Author URI:http://www.vektor-inc.co.jp
Version:1.0.4
*/

/*
一つ目の biz_vektor_themePlus はテーマ側で用意されているフィルターフック名
二つ目の themePlusOriginal はフィルター処理の関数名。任意に変更可ですが下の行の function と同じ名前にして下さい。
【重要】★テーマ識別用引値★は３つとも同じ値を入力して下さい。
【重要】複数の拡張テーマプラグインを同時に有効化する場合は、フィルター処理の関数名がダブらないように注意して下さい。
*/
add_filter('biz_vektor_themePlus','themePlusGarden');
function themePlusGarden($biz_vektor_theme_styles){
    $biz_vektor_theme_styles['garden']['label'] = 'Garden';
    $biz_vektor_theme_styles['garden']['cssPath'] = plugins_url("css/garden.min.css", __FILE__);
    $biz_vektor_theme_styles['garden']['cssPathOldIe'] = plugins_url("css/garden_old_ie.min.css", __FILE__);
    $biz_vektor_theme_styles['garden']['ver'] = '1.0.1';
    return $biz_vektor_theme_styles;
}

/*-------------------------------------------*/
/*	今適応されているテーマを取得
/*-------------------------------------------*/
function is_garden(){
	if (function_exists('biz_vektor_theme_styleSetting'))
	{
		$options = biz_vektor_get_theme_options();
		if ($options['theme_style'] == 'garden') {
			return true;
		}
	}
}

/*-------------------------------------------*/
/*
/*-------------------------------------------*/
add_action( 'admin_init', 'biz_vektor_theme_options_garden_init' );
function biz_vektor_theme_options_garden_init() {
	if (is_garden()){
		if ( false === biz_vektor_get_theme_options_garden() )
			add_option( 'biz_vektor_theme_options_garden' );
			register_setting(
				'biz_vektor_options_garden',
				'biz_vektor_theme_options_garden',
				'biz_vektor_theme_options_garden_validate'
			);
		}
}
/*-------------------------------------------*/
/*	js読み込み
/*-------------------------------------------*/
add_action('wp_footer','garden_js');
function garden_js(){
	if (is_garden()){
		wp_register_script( 'gardenPlugins' , plugins_url("js/garden-plugins.min.js", __FILE__), array('jquery'), '1.0.1');
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'gardenPlugins' );
	}
}

/*-------------------------------------------*/
/*	functionsで毎回呼び出して$optionsに入れる処理を他でする。
/*-------------------------------------------*/
function biz_vektor_get_theme_options_garden() {
	$default = array(
		'theme_plusKeyColor' => '#008b85',
		'theme_plusKeyColorLight' => '#59d3d3',
		'theme_plusKeyColorVeryLight' => '#e6f9f8',
		'theme_plus_pageTitBnrBg' => '',
		);
	return get_option( 'biz_vektor_theme_options_garden',$default);
}

/*-------------------------------------------*/
/*	変数設定
/*-------------------------------------------*/
function biz_vektor_theme_options_garden_validate( $input ) {
	$output = $defaults;
	// 拡張テーマキーカラー
	$output['theme_plusKeyColor'] = $input['theme_plusKeyColor'];
	$output['theme_plusKeyColorLight'] = $input['theme_plusKeyColorLight'];
	$output['theme_plusKeyColorVeryLight'] = $input['theme_plusKeyColorVeryLight'];
	$output['theme_plus_pageTitBnrBg'] = $input['theme_plus_pageTitBnrBg'];
	return apply_filters( 'biz_vektor_theme_options_garden_validate', $output, $input, $defaults );
}


/*-------------------------------------------*/
/*  keycolor filter
/*-------------------------------------------*/
add_filter( 'biz_vektor_keycolors', 'biz_vektor_garden_set_keycolor' );
function biz_vektor_garden_set_keycolor($colors){
    if(is_garden()){
        $options = biz_vektor_get_theme_options_garden();
        $colors['keyColor'] = (isset($options['theme_plusKeyColor']) and $options['theme_plusKeyColor'])? $options['theme_plusKeyColor'] : '#008b85';
    }
    return $colors;
}


/*-------------------------------------------*/
/*	テーマカスタマイザーの設定
/*-------------------------------------------*/
add_action( 'customize_register', 'bizvektor_garden_customize_register' );
function bizvektor_garden_customize_register($wp_customize) {
	if (is_garden()){

	// セクションを追加
	$wp_customize->add_section( 'biz_vektor_garden', array(
		'title'          => 'Garden 設定',
		'priority'       => 500,
	) );
	 // セクションの動作設定
    $add_setting_array = array(
        'default'        => '',
        'type'           => 'option',
        'capability'     => 'edit_theme_options', // 操作権限
    );
	$wp_customize->add_setting( 'biz_vektor_theme_options_garden[theme_plusKeyColor]', $add_setting_array );
	$wp_customize->add_setting( 'biz_vektor_theme_options_garden[theme_plusKeyColorLight]', $add_setting_array );
	$wp_customize->add_setting( 'biz_vektor_theme_options_garden[theme_plusKeyColorVeryLight]', $add_setting_array );
    $wp_customize->add_setting( 'biz_vektor_theme_options_garden[theme_plus_pageTitBnrBg]', $add_setting_array );

		// セクションのUIを作成する
		$wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'keyColor', array(
			'label'    => 'キーカラー',
			'section'  => 'biz_vektor_garden',
			'settings' => 'biz_vektor_theme_options_garden[theme_plusKeyColor]',
		)));
		$wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'keyColorLight', array(
			'label'    => 'キーカラー(明)',
			'section'  => 'biz_vektor_garden',
			'settings' => 'biz_vektor_theme_options_garden[theme_plusKeyColorLight]',
		)));
		$wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'keyColorVeryLight', array(
			'label'    => 'キーカラー(薄)',
			'section'  => 'biz_vektor_garden',
			'settings' => 'biz_vektor_theme_options_garden[theme_plusKeyColorVeryLight]',
		)));

		$wp_customize->add_control( new WP_Customize_Image_Control(
			$wp_customize,
			'page_tit_bnr_bg_url',	// 多分名前は何でもOK
			array(
				'label'     => 'ページタイトル背景画像',						// セクションの中での表示名
				'section'   => 'biz_vektor_garden', 					// テーマカスタマイザーのどのセクションに入れるか
				'settings'  => 'biz_vektor_theme_options_garden[theme_plus_pageTitBnrBg]',	// DBのどこに格納するか
				'priority'  => 20,
			)
		));
		$wp_customize->add_control( 'page_tit_bnr_bg_url_txt',
			array(
				'label'     => 'ページタイトル背景画像URL',
				'section'   => 'biz_vektor_garden',
				'settings'  => 'biz_vektor_theme_options_garden[theme_plus_pageTitBnrBg]',
				'type' => 'text',
				'priority' => 21,
			));
	}
}

/*-------------------------------------------*/
/*	管理画面_テーマオプション_デザインプルダウンの下に設定へのリンクを追加
/*-------------------------------------------*/
// 第一引数：フィルターフック名　／　第二引数：実行関数名
add_filter('themePlusSettingNavi','themePlusSettingNavigarden');
function themePlusSettingNavigarden(){
	global $themePlusSettingNavi;
	if (is_garden()){
		$themePlusSettingNavi = '<p>[ <a href="'.get_admin_url().'customize.php" target="_blank">→ テーマカスタマイザーで色を設定する</a> ]</p>';
	}
	return $themePlusSettingNavi;
}

/*-------------------------------------------*/
/*	タイトルの背景画像
/*-------------------------------------------*/
function garden_the_page_tit_bnr_bg_url(){
	$gardenOptions = biz_vektor_get_theme_options_garden();
	$page_tit_bnr_url = $gardenOptions['theme_plus_pageTitBnrBg'];
	if (!$page_tit_bnr_url) {
		$page_tit_bnr_url = plugins_url("images/pageTitBnr_bg_pen01.jpg", __FILE__);
	}
	$page_tit_bnr_url = apply_filters( 'garden_garden_the_page_tit_bnr_bg_url_custom', $page_tit_bnr_url );
	echo esc_url($page_tit_bnr_url);
}

/*-------------------------------------------*/
/*	head出力
/*-------------------------------------------*/
add_action( 'wp_head','garden_wp_head' ,150 );
function garden_wp_head(){
	if (is_garden()){
		$gardenOptions = biz_vektor_get_theme_options_garden();
		if( isset($gardenOptions['theme_plusKeyColor']))
		$color_key = $gardenOptions['theme_plusKeyColor'];
		if( isset($gardenOptions['theme_plusKeyColorLight']))
		$color_key_light = $gardenOptions['theme_plusKeyColorLight'];
		if( isset($gardenOptions['theme_plusKeyColorVeryLight']))
		$color_key_slight = $gardenOptions['theme_plusKeyColorVeryLight'];
?>
<style type="text/css">
@media (min-width: 660px) {
#pageTitBnr #pageTitInner { background: url('<?php garden_the_page_tit_bnr_bg_url(); ?>') right 50% no-repeat #fff; }
}
</style>
<!--[if lte IE 8]>
<style type="text/css">
#pageTitBnr #pageTitInner { background: url('<?php garden_the_page_tit_bnr_bg_url(); ?>') right bottom no-repeat #fff; }
</style>
<![endif]-->
<?php if ( $color_key || $color_key_light || $color_key_slight ) : ?>
<style type="text/css">
/*-------------------------------------------*/
/*	garden color
/*-------------------------------------------*/
a { color:<?php echo $color_key; ?>; }
a:hover { color:<?php echo $color_key_light; ?>; }

#searchform input[type=submit],
p.form-submit input[type=submit],
form#searchform input#searchsubmit,
#content form input.wpcf7-submit,
#confirm-button input,
a.btn,
.linkBtn a,
input[type=button],
input[type=submit] { background-color:<?php echo $color_key; ?>; }

.moreLink a { background: <?php echo $color_key; ?>; }
.moreLink a:hover { background: <?php echo $color_key_light; ?>; }

#headerTop { border-top: 3px solid <?php echo $color_key; ?>; }
#headContactTel { color:<?php echo $color_key; ?>; }

#gMenu .assistive-text { background-color:<?php echo $color_key; ?>; }

#gMenu .menu li a span { color: <?php echo $color_key; ?>; }
#gMenu .menu li a:hover { border-left-color: <?php echo $color_key; ?>;}

#gMenu .menu li ul li a:hover,
#gMenu .menu li.current_page_item a,
#gMenu .menu li.current_page_item ul.sub-menu li a:hover,
#gMenu .menu li.current_page_ancestor ul.sub-menu li.current_page_item a,
#gMenu .menu li.current-menu-ancestor li a:hover,
#gMenu .menu li.current-page-ancestor li a:hover{ border-left-color: <?php echo $color_key; ?>; }
#gMenu .menu li.current_page_item ul.sub-menu li { border-bottom: none; }

#topPr .topPrOuter h3 a { color: <?php echo $color_key; ?>; }

.sideTower li#sideContact.sideBnr a,
#sideTower li#sideContact.sideBnr a,
#content .infoList .rssBtn a,
form#searchform input#searchsubmit { background-color: <?php echo $color_key; ?>; }

.sideTower li#sideContact.sideBnr a:hover,
#sideTower li#sideContact.sideBnr a:hover,
#content .infoList .rssBtn a:hover,
form#searchform input#searchsubmit:hover { background-color: <?php echo $color_key_light; ?>; }


#panList .innerBox ul a:hover { color:<?php echo $color_key_light; ?>; }

#content h2:after,
#content h1.contentTitle:after,
#content h1.entryPostTitle:after,
.sideTower .localHead:after,
#sideTower .localHead:after,
#content .sideWidget h4:after { border-bottom:3px solid <?php echo $color_key; ?>; }

#content h4,
#content h3,
#content h2,
#content h1.contentTitle,
#content h1.entryPostTitle,
#content .infoList .infoListBox div.entryTxtBox h4.entryTitle a,
.sideTower .localHead,
#sideTower .localHead,
#content .sideWidget h4 { color: <?php echo $color_key; ?>; }

#content .mainFootContact p.mainFootTxt span.mainFootTel { color:<?php echo $color_key; ?>; }
#content .mainFootContact .mainFootBt a { background-color: <?php echo $color_key; ?>; }
#content .mainFootContact .mainFootBt a:hover { background-color: <?php echo $color_key_light; ?>; }

#content .infoList .infoCate a {  }
#content .infoList .infoCate a:hover { background-color: <?php echo $color_key_slight; ?>; color:<?php echo $color_key; ?>; }

.paging span,
.paging a	{ color:<?php echo $color_key; ?>; border-color:<?php echo $color_key; ?>; }
.paging span.current,
.paging a:hover	{ background-color:<?php echo $color_key; ?>; }

	/* アクティブのページ */
.sideTower .sideWidget li a:hover,
.sideTower .sideWidget li.current_page_item a,
.sideTower .sideWidget li.current-cat a,
#sideTower .sideWidget li a:hover,
#sideTower .sideWidget li.current_page_item a,
#sideTower .sideWidget li.current-cat a	{ color:<?php echo $color_key ?>;background-color: <?php echo $color_key_slight; ?>; }
	/* 親がアクティブの子ページ（リセットする） */
.sideTower .sideWidget li.current-cat li a,
.sideTower .sideWidget li.current_page_item li a,
#sideTower .sideWidget li.current-cat li a,
#sideTower .sideWidget li.current_page_item li a	{ color:#333;background-color:inherit; }
	/* 親がアクティブの子ページhover */
.sideTower .sideWidget li.current-cat li a:hover,
.sideTower .sideWidget li.current_page_item li a:hover,
#sideTower .sideWidget li.current-cat li a:hover,
#sideTower .sideWidget li.current_page_item li a:hover	{ color:<?php echo $color_key; ?>;background-color: <?php echo $color_key_slight; ?>; }
	/* 子がアクティブのページ */
.sideTower .sideWidget li li.current-cat a,
.sideTower .sideWidget li li.current_page_item a,
#sideTower .sideWidget li li.current-cat a,
#sideTower .sideWidget li li.current_page_item a { color:<?php echo $color_key; ?>;background-color: <?php echo $color_key_slight; ?>; }
	/* 子がアクティブの孫ページ（リセットする） */
.sideTower .sideWidget li li.current-cat li a,
.sideTower .sideWidget li li.current_page_item li a,
#sideTower .sideWidget li li.current-cat li a,
#sideTower .sideWidget li li.current_page_item li a { color:#333;background-color:inherit; }
	/* 子がアクティブの孫ページhover */
.sideTower .sideWidget li li.current-cat li a:hover,
.sideTower .sideWidget li li.current_page_item li a:hover,
#sideTower .sideWidget li li.current-cat li a:hover,
#sideTower .sideWidget li li.current_page_item li a:hover { color:<?php echo $color_key; ?>;background-color: <?php echo $color_key_slight; ?>; }
.sideTower .ttBoxSection .ttBox a:hover,
#sideTower .ttBoxSection .ttBox a:hover { color: <?php echo $color_key; ?>; }

#pagetop a { background-color: <?php echo $color_key; ?>; }

#footMenu { border-top-color: <?php echo $color_key; ?>; }
#footMenu .menu li a:hover { color:<?php echo $color_key; ?>; }
#footMenu .menu li a:before {  }
/*-------------------------------------------*/
/* pc iPad3より大きい場合
/*-------------------------------------------*/
@media (min-width: 770px) {
#gMenu .menu li { border-bottom: 3px solid #fefefe; }
head/* */body #gMenu .menu li { border-bottom: 3px solid #f3f3f3; } /*ie8で:hoverの順番が先に来ることで、適応されないのでここに追加*/
#gMenu .menu li ul.sub-menu li a,
#gMenu .menu li a:hover { border-left:none; }
#gMenu .menu li.menuFirst a,
#gMenu .menu li.menuFirst a:hover { border-left: 1px solid #e5e5e5 !important; }
#gMenu .menu li:hover { border-bottom-color: <?php echo $color_key; ?>; border-left:none; }
#gMenu .menu li:hover ul li:hover {border-bottom: 1px solid #e5e5e5;}
#gMenu .menu li.current_page_item,
#gMenu .menu li.current_page_ancestor,
#gMenu .menu li.current-page-ancestor,
#gMenu .menu li.current_page_item li a:hover,
#gMenu .menu li.current-menu-ancestor li a:hover,
#gMenu .menu li.current-page-ancestor li a:hover{ border-bottom:3px solid <?php echo $color_key; ?>; border-left: none; }
#gMenu .menu li.current_page_item.menuFirst a,
#gMenu .menu li.current_page_item li a:hover,
#gMenu .menu li.current-menu-ancestor li a:hover,
#gMenu .menu li.current-page-ancestor li a:hover {border-left: none;}
}
</style>
<!--[if lte IE 8]>
<style type="text/css">
#gMenu .menu li:hover { border-bottom-color: <?php echo $color_key;?>; border-left:none; }
#gMenu .menu li.current_page_item,
#gMenu .menu li.current_page_ancestor,
#gMenu .menu li.current-page-ancestor,
#gMenu .menu li.current_page_item li a:hover,
#gMenu .menu li.current-menu-ancestor li a:hover,
#gMenu .menu li.current-page-ancestor li a:hover{ border-bottom:3px solid <?php echo $color_key; ?>; border-left: none; }
#gMenu .menu li.current_page_item ul.sub-menu li {border-bottom: 1px solid #e5e5e5;}
</style>
<![endif]-->
<?php endif; // color ?>

	<?php }
}